/* ***** BEGIN LICENSE BLOCK *****
The contents of this file are subject to the Mozilla Public License
Version 1.1 (the "License"); you may not use this file except in
compliance with the License. You may obtain a copy of the License at
http://www.mozilla.org/MPL/

Software distributed under the License is distributed on an "AS IS"
basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
License for the specific language governing rights and limitations
under the License.

The Original Code is mozilla-uk.org code.

The Initial Developer of the Original Code is Tobias Markus (tobbi@mozilla-uk.org).
All Rights Reserved.

Contributor(s): 
Tobias Markus (tobbi@mozilla-uk.org).

Alternatively, the contents of this file may be used under the terms of
either the GNU General Public License Version 2 or later (the "GPL"), or
the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
in which case the provisions of the GPL or the LGPL are applicable instead
of those above. If you wish to allow use of your version of this file only
under the terms of either the GPL or the LGPL, and not to allow others to
use your version of this file under the terms of the MPL, indicate your
decision by deleting the provisions above and replace them with the notice
and other provisions required by the GPL or the LGPL. If you do not delete
the provisions above, a recipient may use your version of this file under
the terms of any one of the MPL, the GPL or the LGPL.
* ***** END LICENSE BLOCK ***** */

var Memory = {
	count:0, //Current selected cards count
	openTime:1000, //Time in ms selected cards stay visible
	maxOpenCards:2, //Maximal cards to be visible (DO NOT CHANGE)
	totalCardCount:16, //Number of cards in total (must be a number you can divide by 2)
	cardArray:[], //needed later for card randomization (maybe)
	countStarted:false, //Time counter started?
	currentTime:0, //current time in ms
	solvedIn:0, //solved in how many ms?
	FirstSelectedCard:[], //contains first selected card (array pos. 0) and the corresponding image (array pos. 1) as well as the number of the card (array pos. 2)
	imageArray: //contains available foxkeh images without directory and suffix (currently: 36)
	["200701","200702","200703","200704","200705","200706","200707","200708","200709","200710","200711","200712",
	"200801","200802","200803","200804","200805","200806","200807","200808","200809","200810","200811","200812",
	"200901","200902","200903","200904","200905","200906","200907","200908","200909","200910","200911","front","side"], 
	
	Start: function() {
		document.getElementById('remaining').innerHTML=this.totalCardCount+" remaining!";
		this.randomize();
		
		for(var i=0;i<this.totalCardCount;i++) {
			this.newCard(i);
		};
	},
	
	newCard: function(number) {
		var newCard = document.createElement("div");
			newCard.className="memory-card memory-card-closed";
			
		var image = document.createElement("div");
			image.className="memory-card-image";
		
		var randomNumber = Memory.imageArray[Memory.cardArray[number]];
			//Set background image:
			image.style.backgroundImage="url(cards/"+randomNumber+".png)";
			
			newCard.onclick = function() {
				
				//Start counting the time:
				if(Memory.countStarted==false)
					Memory.countUp();
				
				//Set first card and the corresponding image:
				if(Memory.count==0)
					Memory.FirstSelectedCard=[newCard,image,number,randomNumber];
				
				//Turn the card around:
				if(Memory.count<Memory.maxOpenCards) {
					Memory.count++;
					
					switch(image.style.backgroundImage) {
						case "url(cards/200801.png)":
						case "url(cards/200802.png)":
						case "url(cards/200811.png)":
						//Needs white background card:
						newCard.className="memory-card memory-card-open-white";
						break;
					
						case "url(cards/200812.png)":
						//Needs dark blue background card:
						newCard.className="memory-card memory-card-open-blue";
						break;
						
						default:
						//Use default in any other cases:
						newCard.className="memory-card memory-card-open";
						break;
					};
					image.style.visibility="visible";
				}
				if(Memory.count==Memory.maxOpenCards) {
				window.setTimeout(function() {
						Memory.count=0;
						
						//Right:
						if(randomNumber == Memory.FirstSelectedCard[3] &&
						number != Memory.FirstSelectedCard[2]) {
							//Remove both cards (nice, smooth fade effect):
							new Effect.Opacity(newCard, { from: 1, to: 0, duration: 0.5 });
							new Effect.Opacity(image, {from: 1, to: 0, duration: 0.5 });
							
							new Effect.Opacity(Memory.FirstSelectedCard[0], { from: 1, to: 0, duration: 0.5 });
							new Effect.Opacity(Memory.FirstSelectedCard[1], { from: 1, to: 0, duration: 0.5 });
							
							//2 cards less:
							Memory.totalCardCount-=Memory.maxOpenCards;
							
							//Update status:
							document.getElementById('remaining').innerHTML =
							Memory.totalCardCount + " remaining!";
						}
						//Wrong:
						else {
							//Turn both cards around:
							newCard.className = "memory-card memory-card-closed";
							Memory.FirstSelectedCard[0].className = "memory-card memory-card-closed";
							
							//Remove forground images (in any case):
							Memory.FirstSelectedCard[1].style.visibility = "hidden";
							image.style.visibility="hidden";
						};
						
						//Memory solved:
						if(Memory.totalCardCount==0) {
							this.solvedIn=this.currentTime;
							document.getElementById('remaining').innerHTML =
							"You've solved the memory in "+this.solvedIn+" seconds";
							document.getElementById('time').style.display="none";
						};
					//}
				}, Memory.openTime);
				}
			};
		
		//Insert:
		newCard.appendChild(image);
		document.getElementById('main').appendChild(newCard);
	},
	
	randomize:function() {
		//Start random unique number generator (thanks to Barry Pranklin):
		RandomGenerator.NumUnique = (this.totalCardCount / 2);
		RandomGenerator.MaxValue = (this.imageArray.length - 1);
		RandomGenerator.GetUnique();
		
		//Double the numbers in the array:
		var shuffledArray = RandomGenerator.Current.concat(RandomGenerator.Current);
		
		//Use the new shuffle method (thanks to brain4.de):
		shuffledArray.shuffle();
		
		Memory.cardArray = shuffledArray;
	},
	
	countUp: function() {
		var i=0;
		this.countStarted = true;
		window.setInterval(function() {
			//Set duration of memory:
			this.currentTime=0.01*i++;
			
			document.getElementById('time').innerHTML =
			"Time: "+ Math.floor(this.currentTime)+" seconds";
		},1);
	},
};